# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class TestnetBlockchain(str, Enum):
    """
    The testnet blockchain network the resource will be created on or is currently on.
    """

    """
    allowed enum values
    """
    ETH_MINUS_SEPOLIA = 'ETH-SEPOLIA'
    AVAX_MINUS_FUJI = 'AVAX-FUJI'
    MATIC_MINUS_AMOY = 'MATIC-AMOY'
    SOL_MINUS_DEVNET = 'SOL-DEVNET'
    ARB_MINUS_SEPOLIA = 'ARB-SEPOLIA'
    UNI_MINUS_SEPOLIA = 'UNI-SEPOLIA'
    BASE_MINUS_SEPOLIA = 'BASE-SEPOLIA'
    OP_MINUS_SEPOLIA = 'OP-SEPOLIA'
    APTOS_MINUS_TESTNET = 'APTOS-TESTNET'
    ARC_MINUS_TESTNET = 'ARC-TESTNET'
    MONAD_MINUS_TESTNET = 'MONAD-TESTNET'

    @classmethod
    def from_json(cls, json_str: str) -> TestnetBlockchain:
        """Create an instance of TestnetBlockchain from a JSON string"""
        return TestnetBlockchain(json.loads(json_str))


