# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class TokenMonitorScope(str, Enum):
    """
    TokenMonitorScope
    """

    """
    allowed enum values
    """
    SELECTED = 'SELECTED'
    MONITOR_ALL = 'MONITOR_ALL'

    @classmethod
    def from_json(cls, json_str: str) -> TokenMonitorScope:
        """Create an instance of TokenMonitorScope from a JSON string"""
        return TokenMonitorScope(json.loads(json_str))


