# coding: utf-8

"""
    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg





class TokenStandard(str, Enum):
    """
    TokenStandard
    """

    """
    allowed enum values
    """
    ERC20 = 'ERC20'
    ERC721 = 'ERC721'
    ERC1155 = 'ERC1155'
    FUNGIBLE = 'Fungible'
    FUNGIBLEASSET = 'FungibleAsset'
    NONFUNGIBLE = 'NonFungible'
    NONFUNGIBLEEDITION = 'NonFungibleEdition'
    PROGRAMMABLENONFUNGIBLE = 'ProgrammableNonFungible'
    PROGRAMMABLENONFUNGIBLEEDITION = 'ProgrammableNonFungibleEdition'

    @classmethod
    def from_json(cls, json_str: str) -> TokenStandard:
        """Create an instance of TokenStandard from a JSON string"""
        return TokenStandard(json.loads(json_str))


